package de.fhhannover.inform.trust.ifmapj.channel;

import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.exception.InitializationException;
import de.fhhannover.inform.trust.ifmapj.messages.PublishRequest;
import de.fhhannover.inform.trust.ifmapj.messages.SearchRequest;
import de.fhhannover.inform.trust.ifmapj.messages.SearchResult;
import de.fhhannover.inform.trust.ifmapj.messages.SubscribeRequest;

/**
 * Interface describing the Synchronous Send Receive Channel (SSRC) methods.
 * 
 * @author aw
 *
 */
public interface SSRC extends IfmapChannel {
	
	public void newSession() throws IfmapErrorResult, IfmapException;
	
	public void newSession(Integer maxPollResSize) throws IfmapErrorResult, IfmapException;
	
	public void endSession() throws IfmapErrorResult, IfmapException;
	
	public void renewSession() throws IfmapErrorResult, IfmapException;
	
	public void purgePublisher() throws IfmapErrorResult, IfmapException;
	
	public void purgePublisher(String publisherId) throws IfmapErrorResult, IfmapException;
	
	public void publish(PublishRequest req) throws IfmapErrorResult, IfmapException;
	
	public void subscribe(SubscribeRequest req) throws IfmapErrorResult, IfmapException;
	
	public SearchResult search(SearchRequest req) throws IfmapErrorResult, IfmapException;

	/* public void dump(...) throws IOException, IfmapError; */
	
	/**
	 * Open a {@link ARC} corresponding to this {@link SSRC} instance
	 * 
	 * @return
	 */
	public ARC getArc() throws InitializationException;
}
