package de.fhhannover.inform.trust.ifmapj.messages;

/**
 * Encapsulate information about a newSessionResult.
 * 
 * Note, {@link #getMaxPollResultSize()} may return null if no max-poll-result-size
 * attribute was set in the newSessionResult element.
 * 
 * @author aw
 *
 */
class NewSessionResultImpl implements NewSessionResult {
	
	private final String mSessionId;
	private final String mPublisherId;
	private final Integer mMaxPollResultSize;

	NewSessionResultImpl(String sId, String pId, Integer mprs) {
		if (sId == null || pId == null)
			throw new NullPointerException();
		
		mSessionId = sId;
		mPublisherId = pId;
		mMaxPollResultSize = mprs;
		
	}

	NewSessionResultImpl(String sId, String pId) {
		this(sId, pId, null);
	}

	@Override
	public String getSessionId() {
		return mSessionId;
	}

	@Override
	public String getPublisherId() {
		return mPublisherId;
	}

	@Override
	public Integer getMaxPollResultSize() {
		return mMaxPollResultSize;
	}
}
